Learn R Programming

phylter (version 0.9.12)

rename.genes: Name or rename a list of gene trees or matrices

Description

Name or rename a list of gene trees or gene matrices genes. For internal use mostly.

Usage

rename.genes(X, gene.names = NULL)

Value

X with name assigned to each element.

Arguments

X

A list of trees or matrices

gene.names

List of names to assign to the elements of X. Must be of the same length as length(X). If NULL (the default) the object are numbered 1,2,...,length(X).

Examples

Run this code

data(carnivora)

# names before renaming
names(carnivora)

carnivora.renamed<-rename.genes(carnivora, gene.names=as.character(1:length(carnivora)))

# names after renaming
names(carnivora.renamed)

Run the code above in your browser using DataLab